@@ -3,7 +3,7 @@
 *            S i n g l e - P r e c i s i o n   3 x 3   M a t r i x              *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2003,2020 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2003,2022 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -674,6 +674,20 @@ FXMat3f FXMat3f::invert() const {
   }
 
 
+// Orthogonalize matrix
+// Uses Gram-Schmidt orthogonalization on a row-by-row basis
+FXMat3f orthogonalize(const FXMat3f& m){
+  FXMat3f result(m);
+  result[0]/=result[0].length();
+  result[1]-=result[0]*(result[1]*result[0]);
+  result[1]/=result[1].length();
+  result[2]-=result[0]*(result[2]*result[0]);
+  result[2]-=result[1]*(result[2]*result[1]);
+  result[2]/=result[2].length();
+  return result;
+  }
+
+
 // Matrix times vector
 FXVec2f operator*(const FXMat3f& m,const FXVec2f& v){
 #if defined(FOX_HAS_AVX)
